==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/ast.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "L'almacenamientu nun ta disponible temporalmente",
    "Storage invalid" : "Almacenamientu non válidu",
    "Unknown error" : "Fallu desconocíu",
    "All files" : "Tolos ficheros",
    "Recent" : "Reciente",
    "Favorites" : "Favoritos",
    "File could not be found" : "Nun s'atopó el ficheru",
    "Download" : "Descargar",
    "Delete" : "Desaniciar",
    "Home" : "Casa",
    "Close" : "Zarrar",
    "Could not create folder \"{dir}\"" : "Nun pudo crease la carpeta \"{dir}\"",
    "Upload cancelled." : "Xuba encaboxada.",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nun pudo xubise {filename}, paez que ye un directoriu o tien 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nun hai abondu espaciu llibre, tas xubiendo {size1} pero namái falta {size2}",
    "Not enough free space" : "Nun hai espaciu llibre abondo",
    "Uploading …" : "Xubiendo...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Actions" : "Aiciones",
    "Rename" : "Renomar",
    "Copy" : "Copiar",
    "Delete file" : "Desasniciar ficheru",
    "Delete folder" : "Desaniciar",
    "Disconnect storage" : "Desconeutar almacenamientu",
    "Unshare" : "Dexar de compartir",
    "Could not load info for file \"{file}\"" : "Nun pudo cargase la información del ficheru «{file}»",
    "Files" : "Ficheros",
    "Details" : "Detalles",
    "Select" : "Esbillar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "Imposible determinar la fecha",
    "This operation is forbidden" : "La operación ta prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esti direutoriu nun ta disponible, por favor verifica'l rexistru o contacta l'alministrador",
    "Could not move \"{file}\", target exists" : "Nun pudo movese \"{file}\", destín yá esiste",
    "Could not move \"{file}\"" : "Nun pudo movese \"{file}\"",
    "{newName} already exists" : "{newName} yá esiste",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nun pudo renomase \"{fileName}\", yá nun esiste",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nome \"{targetName}\" yá ta n'usu na carpeta \"{dir}\". Por favor, escueyi un nome diferente.",
    "Could not rename \"{fileName}\"" : "Nun pudo renomase \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nun pudo crease'l ficheru \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nun pudo crease'l ficheru \"{file}\" porque yá esiste",
    "Could not create folder \"{dir}\" because it already exists" : "Nun pudo crease la carpeta \"{dir}\" porque yá esiste",
    "Error deleting file \"{fileName}\"." : "Fallu borrando'l ficheru \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nun hai resultaos de gueta n'otres carpetes pa {tag}{filter}{endtag}",
    "Name" : "Nome",
    "Size" : "Tamañu",
    "Modified" : "Modificáu",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n ficheru","%n ficheros"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "You don’t have permission to upload or create files here" : "Nun tienes permisu pa xubir o crear ficheros equí",
    "_Uploading %n file_::_Uploading %n files_" : ["Xubiendo %n ficheru","Xubiendo %n ficheros"],
    "New" : "Nuevu",
    "\"{name}\" is an invalid file name." : "\"{name}\" ye un nome de ficheru inválidu.",
    "File name cannot be empty." : "El nome de ficheru nun pue quedar baleru.",
    "\"{name}\" is not an allowed filetype" : "«{name}» nun ye una triba de ficheru permitida",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'almacenamientu de {owner} ta completu, ¡yá nun se pueden anovar o sincronizar ficheros!",
    "Your storage is full, files can not be updated or synced anymore!" : "L'almacenamientu ta completu, ¡yá nun se pueden anovar o sincronizar ficheros!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'almacenamientu de {owner} ta casi completu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "L'almacenamientu ta casi completu ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["concasa '{filter}'","concasa '{filter}'"],
    "View in folder" : "Ver na carpeta",
    "Copied!" : "¡Copióse!",
    "Path" : "Camín",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "Favoritos",
    "Favorite" : "Favoritu",
    "New folder" : "Nueva carpeta",
    "Upload file" : "Xubir ficheru",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "An error occurred while trying to update the tags" : "Hebo un fallu mientres s'intentaba actualizar les etiquetes",
    "Added to favorites" : "Amestóse a favoritos",
    "\"remote user\"" : "«usuariu remotu»",
    "{user} created {file}" : "{user} creó {file}",
    "{file} was created in a public folder" : "{file} creóse nuna carpeta pública",
    "You changed {file}" : "Camudesti {file}",
    "{user} changed {file}" : "{user} camudó {file}",
    "You deleted {file}" : "Desaniciesti {file}",
    "{user} deleted {file}" : "{user} desanició {file}",
    "You restored {file}" : "Restauresti {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} to {newfile}" : "Renomesti {oldfile} a {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomó {oldfile} a {newfile}",
    "You moved {oldfile} to {newfile}" : "Moviesti {oldfile} a {newfile}",
    "A new file or folder has been <strong>created</strong>" : "<strong>Creóse</strong> un ficheru o carpeta nuevos",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Desanicióse</strong> un ficheru o carpeta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Llendar les notificaciones tocantes a creación y cambeos a tos <strong>ficheros favoritos</strong <em>(namás Stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "<strong>Restauróse</strong> un ficheru o carpeta",
    "Unlimited" : "Non llendáu",
    "Upload (max. %s)" : "Xuba (máx. %s)",
    "Accept" : "Aceutar",
    "Change" : "Camudar",
    "%1$s of %2$s used" : "%1$s de %2$s usao",
    "Settings" : "Axustes",
    "Show hidden files" : "Amosar ficheros ocultos",
    "WebDAV" : "WebDAV",
    "No files in here" : "Nun hai nengún ficheru equí",
    "Upload some content or sync with your devices!" : "¡Xuba algún conteníu o sincroniza colos sos preseos!",
    "No entries found in this folder" : "Nenguna entrada en esta carpeta",
    "Select all" : "Esbillar too",
    "Upload too large" : "La xuba ye abondo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los ficheros que tas intentando xubir perpasen el tamañu máximu pa les xubíes de ficheros nesti servidor.",
    "No favorites yet" : "Entá nun hai favoritos",
    "Files and folders you mark as favorite will show up here" : "Los ficheros y carpetes que marque como favoritos apaecerán equí",
    "Tags" : "Etiquetes",
    "Deleted files" : "Ficheros desaniciaos",
    "Shares" : "Comparticiones",
    "Shared with others" : "Compartío con otros",
    "Shared with you" : "Shared with you",
    "Shared by link" : "Compartíos per enllaz",
    "Text file" : "Ficheru de testu",
    "New text file.txt" : "Nuevu testu ficheru.txt",
    "File handling" : "Alministración de ficheros",
    "Maximum upload size" : "Tamañu máximu de xubida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM pue retrasase 5 minutos pa que los cambeos s'apliquen.",
    "Missing permissions to edit from here." : "Falten permisos pa editar dende equí.",
    "Cancel upload" : "Encaboxar xuba"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/ast.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "L'almacenamientu nun ta disponible temporalmente",
    "Storage invalid" : "Almacenamientu non válidu",
    "Unknown error" : "Fallu desconocíu",
    "File could not be found" : "Nun s'atopó el ficheru",
    "Download" : "Descargar",
    "Delete" : "Desaniciar",
    "Home" : "Casa",
    "Close" : "Zarrar",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "Nun pudo crease la carpeta \"{dir}\"",
    "Upload cancelled." : "Xuba encaboxada.",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nun pudo xubise {filename}, paez que ye un directoriu o tien 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nun hai abondu espaciu llibre, tas xubiendo {size1} pero namái falta {size2}",
    "Not enough free space" : "Nun hai espaciu llibre abondo",
    "Uploading …" : "Xubiendo...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Actions" : "Aiciones",
    "Rename" : "Renomar",
    "Copy" : "Copiar",
    "Delete file" : "Desasniciar ficheru",
    "Delete folder" : "Desaniciar",
    "Disconnect storage" : "Desconeutar almacenamientu",
    "Could not load info for file \"{file}\"" : "Nun pudo cargase la información del ficheru «{file}»",
    "Files" : "Ficheros",
    "Details" : "Detalles",
    "Select" : "Esbillar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "Imposible determinar la fecha",
    "This operation is forbidden" : "La operación ta prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esti direutoriu nun ta disponible, por favor verifica'l rexistru o contacta l'alministrador",
    "Could not move \"{file}\", target exists" : "Nun pudo movese \"{file}\", destín yá esiste",
    "Could not move \"{file}\"" : "Nun pudo movese \"{file}\"",
    "{newName} already exists" : "{newName} yá esiste",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nun pudo renomase \"{fileName}\", yá nun esiste",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nome \"{targetName}\" yá ta n'usu na carpeta \"{dir}\". Por favor, escueyi un nome diferente.",
    "Could not rename \"{fileName}\"" : "Nun pudo renomase \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nun pudo crease'l ficheru \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nun pudo crease'l ficheru \"{file}\" porque yá esiste",
    "Could not create folder \"{dir}\" because it already exists" : "Nun pudo crease la carpeta \"{dir}\" porque yá esiste",
    "Error deleting file \"{fileName}\"." : "Fallu borrando'l ficheru \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nun hai resultaos de gueta n'otres carpetes pa {tag}{filter}{endtag}",
    "Name" : "Nome",
    "Size" : "Tamañu",
    "Modified" : "Modificáu",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n ficheru","%n ficheros"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "You don’t have permission to upload or create files here" : "Nun tienes permisu pa xubir o crear ficheros equí",
    "_Uploading %n file_::_Uploading %n files_" : ["Xubiendo %n ficheru","Xubiendo %n ficheros"],
    "New" : "Nuevu",
    "\"{name}\" is an invalid file name." : "\"{name}\" ye un nome de ficheru inválidu.",
    "File name cannot be empty." : "El nome de ficheru nun pue quedar baleru.",
    "\"{name}\" is not an allowed filetype" : "«{name}» nun ye una triba de ficheru permitida",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'almacenamientu de {owner} ta completu, ¡yá nun se pueden anovar o sincronizar ficheros!",
    "Your storage is full, files can not be updated or synced anymore!" : "L'almacenamientu ta completu, ¡yá nun se pueden anovar o sincronizar ficheros!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "L'almacenamientu de {owner} ta casi completu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "L'almacenamientu ta casi completu ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["concasa '{filter}'","concasa '{filter}'"],
    "View in folder" : "Ver na carpeta",
    "Copied!" : "¡Copióse!",
    "Path" : "Camín",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "Favoritos",
    "Favorite" : "Favoritu",
    "New folder" : "Nueva carpeta",
    "Upload file" : "Xubir ficheru",
    "Recent" : "Reciente",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "An error occurred while trying to update the tags" : "Hebo un fallu mientres s'intentaba actualizar les etiquetes",
    "Added to favorites" : "Amestóse a favoritos",
    "\"remote user\"" : "«usuariu remotu»",
    "{user} created {file}" : "{user} creó {file}",
    "{file} was created in a public folder" : "{file} creóse nuna carpeta pública",
    "You changed {file}" : "Camudesti {file}",
    "{user} changed {file}" : "{user} camudó {file}",
    "You deleted {file}" : "Desaniciesti {file}",
    "{user} deleted {file}" : "{user} desanició {file}",
    "You restored {file}" : "Restauresti {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} to {newfile}" : "Renomesti {oldfile} a {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renomó {oldfile} a {newfile}",
    "You moved {oldfile} to {newfile}" : "Moviesti {oldfile} a {newfile}",
    "A file or folder has been <strong>changed</strong>" : "<strong>Camudóse</strong> un ficheru o carpeta",
    "All files" : "Tolos ficheros",
    "Unlimited" : "Non llendáu",
    "Upload (max. %s)" : "Xuba (máx. %s)",
    "Accept" : "Aceutar",
    "in %s" : "en %s",
    "Change" : "Camudar",
    "Tags" : "Etiquetes",
    "%1$s of %2$s used" : "%1$s de %2$s usao",
    "Settings" : "Axustes",
    "Show hidden files" : "Amosar ficheros ocultos",
    "WebDAV" : "WebDAV",
    "No files in here" : "Nun hai nengún ficheru equí",
    "Upload some content or sync with your devices!" : "¡Xuba algún conteníu o sincroniza colos sos preseos!",
    "No entries found in this folder" : "Nenguna entrada en esta carpeta",
    "Select all" : "Esbillar too",
    "Upload too large" : "La xuba ye abondo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los ficheros que tas intentando xubir perpasen el tamañu máximu pa les xubíes de ficheros nesti servidor.",
    "No favorites yet" : "Entá nun hai favoritos",
    "Files and folders you mark as favorite will show up here" : "Los ficheros y carpetes que marque como favoritos apaecerán equí",
    "Deleted files" : "Ficheros desaniciaos",
    "Shares" : "Comparticiones",
    "Shared with others" : "Compartío con otros",
    "Shared with you" : "Shared with you",
    "Shared by link" : "Compartíos per enllaz",
    "Text file" : "Ficheru de testu",
    "New text file.txt" : "Nuevu testu ficheru.txt",
    "Unshare" : "Dexar de compartir",
    "A new file or folder has been <strong>created</strong>" : "<strong>Creóse</strong> un ficheru o carpeta nuevos",
    "A file or folder has been <strong>deleted</strong>" : "<strong>Desanicióse</strong> un ficheru o carpeta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Llendar les notificaciones tocantes a creación y cambeos a tos <strong>ficheros favoritos</strong <em>(namás Stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "<strong>Restauróse</strong> un ficheru o carpeta"
},
"nplurals=2; plural=(n != 1);");
